doapfiend

Package doapfiend |
[hide private]
[frames] | no frames]

# Package doapfiend

source code

# doapfiend

http://trac.doapspace.org/doapfiend

## Description

doapfiend is a command-line client and library for querying, creating and displaying DOAP (Description of a Project) RDF profiles.

doapfiend uses RDFAlchemy and rdflib to parse and serialize DOAP.

## Plugins

Plugins can be written for editing DOAP, scraping websites and creating DOAP, searching for DOAP in SPARQL endpoints, displaying DOAP in various formats such as HTML etc.

Version: 0.1.0

Author: Rob Cakebread <rob@doapspace.org>

Copyright: (C) 2007-2008 Rob Cakebread

License: BSD-2

Submodules | [hide private]
doapfiend.cli: Command-line tool for querying, serializing and displaying DOAP doapfiend.doaplib: Library for parsing, displaying, querying and serializing DOAP doapfiend.model: Model of a DOAP profile using RDFAlchemy doapfiend.utils: General purpose helper functions and classes for doapfiend You'll probably want to use doaplib for most cases.

Variables | [hide private]
| log = `logging.getLogger()`